#!/usr/bin/env bash

########################################################################################################################
# This job creates symlinks between the output of ecEarth and CMOR json tables 
# to be executed by the tasks.
#
# In this script, I call data the original data to be symlinked and workflow the 
# workflow that is executing this script
#
# VARIABLE INDEX:
#
# internal autosubmit:
#
# EXPID: autosubmit (this!) experiment indentifier
# CURRENT_ROOTDIR: path to files of the experiment in remote
# MEMBER: this workflow's member
#
# in expdef_cxxx.conf (if you use TODO INSERT HASH) data you should not change this:
#
# ECEARTH_OUTPUT_MEMBER: original data member (fc0, fc1). It shoud match MEMBER
# ECEARTH_OUTPUT_CHUNK: original data chunk.
# ECEARTH_OUTPUT_SDATE: original data startdate. It should match SDATE.
# ECEARTH_OUTPUT_EXPID: original data Autosubmit experiment identifier. 
#
# Manuel G. Marciani
# BSC-CNS - Earth Sciences Department
# 2024
#
########################################################################################################################

CURRENT_EXPID=%EXPID%
CURRENT_ROOTDIR=%CURRENT_ROOTDIR%
CURRENT_MEMBER=%MEMBER%
DATA_MEMBER=%ECEARTH_OUTPUT_MEMBER%
DATA_CHUNK=%ECEARTH_OUTPUT_CHUNK%
DATA_SDATE=%ECEARTH_OUTPUT_SDATE%
DATA_EXPID=%ECEARTH_OUTPUT_EXPID%

# check if the start date from the data and the workflow are the same
if [[ "$CURRENT_SDATE" != "$DATA_SDATE" ]]; then
    # print to stderr
    >&2 echo "Data's start date and this workflow's start date should be the same."
    exit $ERRCODE
fi

# check if the member from the data and the workflow are the same
if [[ "$CURRENT_MEMBER" != "$DATA_MEMBER" ]]; then
    # print to stderr
    >&2 echo "Data's member and this workflow's member should be the same."
    exit $ERRCODE
fi

# check if the folder exists
# TODO this script is broken for a chunksize of 12 months!  
mkdir -p ${CURRENT_ROOTDIR}/${DATA_SDATE}/${DATA_MEMBER}/runtime/output/ifs/${DATA_CHUNK} 
pushd ${CURRENT_ROOTDIR}/${DATA_SDATE}/${DATA_MEMBER}/runtime/output/ifs/${DATA_CHUNK}
ln -s %ECEARTH_OUTPUT%/${DATA_SDATE}/${DATA_MEMBER}/runtime/output/ifs/${DATA_CHUNK}/ICMGGa79h+000000 ICMGG%EXPID%+000000
ln -s %ECEARTH_OUTPUT%/${DATA_SDATE}/${DATA_MEMBER}/runtime/output/ifs/${DATA_CHUNK}/ICMGGa79h+000000 ICMSH%EXPID%+000000
ln -s %ECEARTH_OUTPUT%/${DATA_SDATE}/${DATA_MEMBER}/runtime/output/ifs/${DATA_CHUNK}/ICMGGa79h+000000 ICMGG%EXPID%+199002
ln -s %ECEARTH_OUTPUT%/${DATA_SDATE}/${DATA_MEMBER}/runtime/output/ifs/${DATA_CHUNK}/ICMGGa79h+000000 ICMSH%EXPID%+199002
popd 

mkdir -p ${CURRENT_ROOTDIR}/${DATA_SDATE}/${DATA_MEMBER}/runtime/output/nemo/
pushd ${CURRENT_ROOTDIR}/${DATA_SDATE}/${DATA_MEMBER}/runtime/output/nemo/
ln -s %ECEARTH_OUTPUT%/${DATA_SDATE}/${DATA_MEMBER}/runtime/output/nemo/ofx-data 
mkdir 001
pushd 001 
ln -s %ECEARTH_OUTPUT%/${DATA_SDATE}/${DATA_MEMBER}/runtime/output/nemo/${DATA_CHUNK}/a79h_1d_19900201_19900228_lim_grid_T_2D.nc ${CURRENT_EXPID}_1d_19900201_19900228_lim_grid_T_2D.nc
ln -s %ECEARTH_OUTPUT%/${DATA_SDATE}/${DATA_MEMBER}/runtime/output/nemo/${DATA_CHUNK}/a79h_1d_19900201_19900228_lim_grid_U_2D.nc ${CURRENT_EXPID}_1d_19900201_19900228_lim_grid_U_2D.nc
ln -s %ECEARTH_OUTPUT%/${DATA_SDATE}/${DATA_MEMBER}/runtime/output/nemo/${DATA_CHUNK}/a79h_1d_19900201_19900228_lim_grid_V_2D.nc ${CURRENT_EXPID}_1d_19900201_19900228_lim_grid_V_2D.nc
ln -s %ECEARTH_OUTPUT%/${DATA_SDATE}/${DATA_MEMBER}/runtime/output/nemo/${DATA_CHUNK}/a79h_1d_19900201_19900228_opa_grid_T_2D.nc ${CURRENT_EXPID}_1d_19900201_19900228_opa_grid_T_2D.nc
ln -s %ECEARTH_OUTPUT%/${DATA_SDATE}/${DATA_MEMBER}/runtime/output/nemo/${DATA_CHUNK}/a79h_1m_19900201_19900228_lim_grid_T_2D.nc ${CURRENT_EXPID}_1m_19900201_19900228_lim_grid_T_2D.nc
ln -s %ECEARTH_OUTPUT%/${DATA_SDATE}/${DATA_MEMBER}/runtime/output/nemo/${DATA_CHUNK}/a79h_1m_19900201_19900228_lim_grid_U_2D.nc ${CURRENT_EXPID}_1m_19900201_19900228_lim_grid_U_2D.nc
ln -s %ECEARTH_OUTPUT%/${DATA_SDATE}/${DATA_MEMBER}/runtime/output/nemo/${DATA_CHUNK}/a79h_1m_19900201_19900228_lim_grid_V_2D.nc ${CURRENT_EXPID}_1m_19900201_19900228_lim_grid_V_2D.nc
ln -s %ECEARTH_OUTPUT%/${DATA_SDATE}/${DATA_MEMBER}/runtime/output/nemo/${DATA_CHUNK}/a79h_1m_19900201_19900228_opa_grid_1point.nc ${CURRENT_EXPID}_1m_19900201_19900228_opa_grid_1point.nc
ln -s %ECEARTH_OUTPUT%/${DATA_SDATE}/${DATA_MEMBER}/runtime/output/nemo/${DATA_CHUNK}/a79h_1m_19900201_19900228_opa_grid_ptr_T_3basin_2D.nc ${CURRENT_EXPID}_1m_19900201_19900228_opa_grid_ptr_T_3basin_2D.nc
ln -s %ECEARTH_OUTPUT%/${DATA_SDATE}/${DATA_MEMBER}/runtime/output/nemo/${DATA_CHUNK}/a79h_1m_19900201_19900228_opa_grid_T_2D.nc ${CURRENT_EXPID}_1m_19900201_19900228_opa_grid_T_2D.nc
ln -s %ECEARTH_OUTPUT%/${DATA_SDATE}/${DATA_MEMBER}/runtime/output/nemo/${DATA_CHUNK}/a79h_1m_19900201_19900228_opa_grid_T_3D.nc ${CURRENT_EXPID}_1m_19900201_19900228_opa_grid_T_3D.nc
ln -s %ECEARTH_OUTPUT%/${DATA_SDATE}/${DATA_MEMBER}/runtime/output/nemo/${DATA_CHUNK}/a79h_1m_19900201_19900228_opa_grid_U_2D.nc ${CURRENT_EXPID}_1m_19900201_19900228_opa_grid_U_2D.nc
ln -s %ECEARTH_OUTPUT%/${DATA_SDATE}/${DATA_MEMBER}/runtime/output/nemo/${DATA_CHUNK}/a79h_1m_19900201_19900228_opa_grid_U_3D.nc ${CURRENT_EXPID}_1m_19900201_19900228_opa_grid_U_3D.nc
ln -s %ECEARTH_OUTPUT%/${DATA_SDATE}/${DATA_MEMBER}/runtime/output/nemo/${DATA_CHUNK}/a79h_1m_19900201_19900228_opa_grid_V_2D.nc ${CURRENT_EXPID}_1m_19900201_19900228_opa_grid_V_2D.nc
ln -s %ECEARTH_OUTPUT%/${DATA_SDATE}/${DATA_MEMBER}/runtime/output/nemo/${DATA_CHUNK}/a79h_1m_19900201_19900228_opa_grid_V_3D.nc ${CURRENT_EXPID}_1m_19900201_19900228_opa_grid_V_3D.nc
ln -s %ECEARTH_OUTPUT%/${DATA_SDATE}/${DATA_MEMBER}/runtime/output/nemo/${DATA_CHUNK}/a79h_1m_19900201_19900228_opa_grid_W_3D.nc ${CURRENT_EXPID}_1m_19900201_19900228_opa_grid_W_3D.nc
ln -s %ECEARTH_OUTPUT%/${DATA_SDATE}/${DATA_MEMBER}/runtime/output/nemo/${DATA_CHUNK}/a79h_1m_19900201_19900228_opa_vert_sum.nc ${CURRENT_EXPID}_1m_19900201_19900228_opa_vert_sum.nc
ln -s %ECEARTH_OUTPUT%/${DATA_SDATE}/${DATA_MEMBER}/runtime/output/nemo/${DATA_CHUNK}/a79h_1m_19900201_19900228_opa_zoom_2000_sum.nc ${CURRENT_EXPID}_1m_19900201_19900228_opa_zoom_2000_sum.nc
ln -s %ECEARTH_OUTPUT%/${DATA_SDATE}/${DATA_MEMBER}/runtime/output/nemo/${DATA_CHUNK}/a79h_1m_19900201_19900228_opa_zoom_300_sum.nc ${CURRENT_EXPID}_1m_19900201_19900228_opa_zoom_300_sum.nc
ln -s %ECEARTH_OUTPUT%/${DATA_SDATE}/${DATA_MEMBER}/runtime/output/nemo/${DATA_CHUNK}/a79h_1m_19900201_19900228_opa_zoom_700_sum.nc ${CURRENT_EXPID}_1m_19900201_19900228_opa_zoom_700_sum.nc
ln -s %ECEARTH_OUTPUT%/${DATA_SDATE}/${DATA_MEMBER}/runtime/output/nemo/${DATA_CHUNK}/a79h_1y_19900201_19900228_opa_grid_T_2D.nc ${CURRENT_EXPID}_1y_19900201_19900228_opa_grid_T_2D.nc
popd 
popd 
